@@ -86,7 +86,7 @@ impl<'a> Context<'a> {
     /// Identify the current working directory and create an instance of Context
     /// for it. "logical-path" is used when a shell allows the "current working directory"
     /// to be something other than a file system path (like powershell provider specific paths).
-    pub fn new(arguments: Properties, target: Target) -> Context<'a> {
+    pub fn new(arguments: Properties, target: Target) -> Self {
         let shell = Context::get_shell();
 
         // Retrieve the "current directory".
@@ -126,7 +126,7 @@ impl<'a> Context<'a> {
         path: PathBuf,
         logical_path: PathBuf,
         env: Env<'a>,
-    ) -> Context<'a> {
+    ) -> Self {
         let config = StarshipConfig::initialize(&get_config_path_os(&env));
 
         // If the vector is zero-length, we should pretend that we didn't get a
@@ -184,7 +184,7 @@ impl<'a> Context<'a> {
     }
 
     /// Sets the context config, overwriting the existing config
-    pub fn set_config(mut self, config: toml::Table) -> Context<'a> {
+    pub fn set_config(mut self, config: toml::Table) -> Self {
         self.root_config = StarshipRootConfig::load(&config);
         self.config = StarshipConfig {
             config: Some(config),
