@@ -1,4 +1,3 @@
-use nu_ansi_term::Style;
 use pest::error::Error as PestError;
 use rayon::prelude::*;
 use std::borrow::Cow;
@@ -6,7 +5,7 @@ use std::collections::{BTreeMap, BTreeSet};
 use std::error::Error;
 use std::fmt;
 
-use crate::config::parse_style_string;
+use crate::config::{parse_style_string, Style};
 use crate::context::{Context, Shell};
 use crate::segment::Segment;
 
@@ -103,11 +102,11 @@ impl<'a> StringFormatter<'a> {
     /// parameter and returns the one of the following values:
     ///
     /// - `None`: This variable will be reserved for further mappers. If it is `None` when
-    /// `self.parse()` is called, it will be dropped.
+    ///   `self.parse()` is called, it will be dropped.
     ///
     /// - `Some(Err(StringFormatterError))`: This variable will throws `StringFormatterError` when
-    /// `self.parse()` is called. Return this if some fatal error occurred and the format string
-    /// should not be rendered.
+    ///   `self.parse()` is called. Return this if some fatal error occurred and the format string
+    ///   should not be rendered.
     ///
     /// - `Some(Ok(_))`: The value of this variable will be displayed in the format string.
     ///
@@ -223,7 +222,7 @@ impl<'a> StringFormatter<'a> {
             .par_iter_mut()
             .filter(|(_, value)| value.is_none())
             .for_each(|(key, value)| {
-                *value = mapper(key).map(|var| var.map(std::convert::Into::into));
+                *value = mapper(key).map(|var| var.map(Into::into));
             });
         self
     }
@@ -487,7 +486,7 @@ mod tests {
         let style = Some(Color::Red.bold());
 
         let formatter = StringFormatter::new(FORMAT_STR).unwrap().map(empty_mapper);
-        let result = formatter.parse(style, None).unwrap();
+        let result = formatter.parse(style.map(Into::into), None).unwrap();
         let mut result_iter = result.iter();
         match_next!(result_iter, "text", style);
     }
@@ -562,7 +561,7 @@ mod tests {
         let inner_style = Some(Color::Blue.normal());
 
         let formatter = StringFormatter::new(FORMAT_STR).unwrap().map(empty_mapper);
-        let result = formatter.parse(outer_style, None).unwrap();
+        let result = formatter.parse(outer_style.map(Into::into), None).unwrap();
         let mut result_iter = result.iter();
         match_next!(result_iter, "outer ", outer_style);
         match_next!(result_iter, "middle ", middle_style);
@@ -618,9 +617,9 @@ mod tests {
 
         let mut segments: Vec<Segment> = Vec::new();
         segments.extend(Segment::from_text(None, "styless"));
-        segments.extend(Segment::from_text(styled_style, "styled"));
+        segments.extend(Segment::from_text(styled_style.map(Into::into), "styled"));
         segments.extend(Segment::from_text(
-            styled_no_modifier_style,
+            styled_no_modifier_style.map(Into::into),
             "styled_no_modifier",
         ));
 
